==> neo4j-kernel-2.2.5-sources.jar: org/neo4j/kernel/impl/core/Token.java <==
/*
 * Copyright (c) 2002-2015 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.impl.core;

public class Token
{
    private final String name;
    private final int id;

    public Token( String name, int id )
    {
        this.name = name;
        this.id = id;
    }

    public String name()
    {
        return name;
    }

    public int id()
    {
        return this.id;
    }

    @Override
    public int hashCode()
    {
        return id;
    }

    @Override
    public boolean equals( Object obj )
    {
        if ( !(obj instanceof Token) )
        {
            return false;
        }
        return id == ((Token) obj).id;
    }

    @Override
    public String toString()
    {
        return getClass().getSimpleName() + "[name:" + name + ", id:" + id + "]";
    }
}

==> neo4j-kernel-2.3.0-sources.jar: org/neo4j/kernel/impl/core/Token.java <==
/*
 * Copyright (c) 2002-2015 "Neo Technology,"
 * Network Engine for Objects in Lund AB [http://neotechnology.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.impl.core;

public class Token
{
    private final String name;
    private final int id;

    public Token( String name, int id )
    {
        this.name = name;
        this.id = id;
    }

    public String name()
    {
        return name;
    }

    public int id()
    {
        return this.id;
    }

    @Override
    public int hashCode()
    {
        return id;
    }

    @Override
    public boolean equals( Object obj )
    {
        if ( !(obj instanceof Token) )
        {
            return false;
        }
        return id == ((Token) obj).id;
    }

    @Override
    public String toString()
    {
        return getClass().getSimpleName() + "[name:" + name + ", id:" + id + "]";
    }

    public static class Factory implements TokenFactory<Token>
    {
        @Override
        public Token newToken( String name, int id )
        {
            return new Token( name, id );
        }
    }
}
